@@ -3,9 +3,12 @@ test_that("cultivar", {
     wheat <- read_apsimx(system.file("extdata/Wheat.json", package = "rapsimng"))
     a <- get_cultivar(wheat)
     expect_equal(nrow(a), 30)
+    expect_equal(length(a$name), 30)
+    expect_equal(length(a$standard_name), 30)
+    expect_equal(length(a$parameter), 30)
+    expect_equal(length(a$value), 30)
     a <- get_cultivar(wheat, alias = FALSE)
     expect_equal(nrow(a), 25)
-
 })
 
 
